@@ -33,9 +33,10 @@
 #  define KHTML_DEPRECATED_NO_EXPORT KHTML_NO_EXPORT KHTML_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KHTML_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KHTML_NO_DEPRECATED
+#    define KHTML_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
